@@ -1,12 +1,8 @@
-# encoding: utf-8
-
-from __future__ import absolute_import, unicode_literals
-
-import subprocess
+import subprocess  # NOQA: B404
 
 
 def _process(action):
-    subprocess.call(('./start-solr-test-server.sh', action))
+    subprocess.call(("./start-solr-test-server.sh", action))  # NOQA: B603
 
 
 def prepare():
